| jlview_gc_pressure | R Documentation |
Returns the current amount of Julia memory pinned by jlview objects and the threshold at which forced GC is triggered.
jlview_gc_pressure()
A list with pinned_bytes and threshold
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.