| jlview_named_matrix | R Documentation |
Creates a zero-copy ALTREP view of a Julia NamedArray matrix, preserving row and column names as dimnames.
jlview_named_matrix(julia_named_matrix)
julia_named_matrix |
A JuliaObject referencing a Julia NamedArray matrix |
An ALTREP matrix with dimnames set from the Julia NamedArray
## Not run:
JuliaCall::julia_setup()
JuliaCall::julia_command("using NamedArrays")
m <- JuliaCall::julia_eval('NamedArray(randn(3,2), (["a","b","c"], ["x","y"]))')
x <- jlview_named_matrix(m)
rownames(x) # returns c("a", "b", "c")
colnames(x) # returns c("x", "y")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.