Unpins the Julia array immediately, freeing memory without waiting for R's garbage collector. After release, accessing the data will error.
Unpins the Julia array immediately, freeing memory without waiting for R's garbage collector. After release, accessing the data will error.