Skip to contents

Returns the current amount of Julia memory pinned by jlview objects and the threshold at which forced GC is triggered.

Usage

jlview_gc_pressure()

Value

A list with pinned_bytes and threshold