R/release.R
jlview_gc_pressure.Rd
Returns the current amount of Julia memory pinned by jlview objects and the threshold at which forced GC is triggered.
jlview_gc_pressure()
A list with pinned_bytes and threshold
pinned_bytes
threshold