jlview_set_gc_threshold: Set the GC pressure threshold

View source: R/release.R

jlview_set_gc_thresholdR Documentation

Set the GC pressure threshold

Description

When total pinned bytes exceeds this threshold, jlview forces an R garbage collection to reclaim stale ALTREP objects. Default is 10GB.

Usage

jlview_set_gc_threshold(bytes)

Arguments

bytes

Threshold in bytes (numeric)

Value

Invisible NULL


jlview documentation built on March 24, 2026, 1:07 a.m.