| jlview_set_gc_threshold | R Documentation |
When total pinned bytes exceeds this threshold, jlview forces an R garbage collection to reclaim stale ALTREP objects. Default is 10GB.
jlview_set_gc_threshold(bytes)
bytes |
Threshold in bytes (numeric) |
Invisible NULL
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.